@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -13,7 +13,7 @@
 import itertools
 
 from lollypop.sqlcursor import SqlCursor
-from lollypop.define import App, Type, OrderBy
+from lollypop.define import App, Type, OrderBy, LovedFlags
 from lollypop.utils import get_network_available, sql_escape
 
 
@@ -104,6 +104,7 @@ class GenresDatabase:
                      albums.name\
                      COLLATE NOCASE COLLATE LOCALIZED"
         with SqlCursor(self.__db) as sql:
+            filters = ()
             request = "SELECT albums.rowid\
                        FROM albums, album_genres, genres,\
                             album_artists, artists\
@@ -114,9 +115,10 @@ class GenresDatabase:
             if not get_network_available():
                 request += " AND albums.synced!=%s" % Type.NONE
             if ignore:
-                request += " AND albums.loved != -1"
+                request += " AND not albums.loved & ?"
+                filters += (LovedFlags.SKIPPED,)
             request += order
-            result = sql.execute(request)
+            result = sql.execute(request, filters)
             return list(itertools.chain(*result))
 
     def get(self):
