@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -46,15 +46,6 @@ class ArtistMenu(Gio.Menu):
             App().add_action(action)
             action.connect("change-state", self.__on_change_state)
             self.append(_("Show tracks"), "app.show-artist-tracks")
-            if not show_artist_tracks:
-                action = Gio.SimpleAction.new_stateful(
-                    "show-year-below-name",
-                    None,
-                    GLib.Variant.new_boolean(
-                        App().settings.get_value("show-year-below-name")))
-                App().add_action(action)
-                action.connect("change-state", self.__on_change_state)
-                self.append(_("Show year"), "app.show-year-below-name")
             action = Gio.SimpleAction.new_stateful(
                 "play-featured",
                 None,
@@ -68,7 +59,7 @@ class ArtistMenu(Gio.Menu):
             self.append_section(_("Playback"),
                                 ArtistPlaybackMenu(artist_id, storage_type))
         menu = Gio.Menu()
-        self.append_section(_("Artist"), menu)
+        self.append_section(_("Add to"), menu)
         storage_type = get_default_storage_type()
         album_ids = App().albums.get_ids([], [artist_id], storage_type, False)
         albums = [Album(album_id) for album_id in album_ids]
